==> gmt_5.4.2%2Bdfsg.orig.tar.xz: gmt-5.4.2/doc/examples/ex39/example_39.sh <==
#!/bin/bash
#               GMT EXAMPLE 39
#               $Id: example_39.sh 17711 2017-03-17 20:55:30Z pwessel $
#
# Purpose:      Illustrate evaluation of spherical harmonic coefficients
# GMT modules:  psscale, pstext, makecpt, grdimage, sph2grd
# Unix progs:   rm
#
ps=example_39.ps

# Evaluate the first 180, 90, and 30 order/degrees of Venus spherical
# harmonics topography model, skipping the L = 0 term (radial mean).
# File truncated from http://www.ipgp.fr/~wieczor/SH/VenusTopo180.txt.zip
# Wieczorek, M. A., Gravity and topography of the terrestrial planets,
#   Treatise on Geophysics, 10, 165-205, doi:10.1016/B978-044452748-6/00156-5, 2007

gmt sph2grd VenusTopo180.txt -I1 -Rg -Ng -Gv1.nc -F1/1/25/30
gmt sph2grd VenusTopo180.txt -I1 -Rg -Ng -Gv2.nc -F1/1/85/90
gmt sph2grd VenusTopo180.txt -I1 -Rg -Ng -Gv3.nc -F1/1/170/180
gmt grd2cpt v3.nc -Crainbow -E > t.cpt
gmt grdimage v1.nc -I+a45+nt0.75 -JG90/30/5i -P -K -Bg -Ct.cpt -X3i -Y1.1i > $ps
echo 4 4.5 L = 30 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
gmt psscale --FORMAT_FLOAT_MAP="%'g" -Ct.cpt -O -K -Dx1.25i/-0.2i+jTC+w5.5i/0.1i+h -Bxaf -By+lm >> $ps
gmt grdimage v2.nc -I+a45+nt0.75 -JG -O -K -Bg -Ct.cpt -X-1.25i -Y1.9i >> $ps
echo 4 4.5 L = 90 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
gmt grdimage v3.nc -I+a45+nt0.75 -JG -O -K -Bg -Ct.cpt -X-1.25i -Y1.9i >> $ps
echo 4 4.5 L = 180 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
echo 3.75 5.4 Venus Spherical Harmonic Model | gmt pstext -R0/6/0/6 -Jx1i -O -F+f24p+jCM -N >> $ps
rm -f v?.nc t.cpt

==> gmt_6.0.0~rc1%2Bdfsg.orig.tar.xz: gmt-6.0.0rc1/doc/examples/ex39/example_39.sh <==
#!/usr/bin/env bash
#               GMT EXAMPLE 39
#
# Purpose:      Illustrate evaluation of spherical harmonic coefficients
# GMT modules:  psscale, pstext, makecpt, grdimage, sph2grd
# Unix progs:   rm
#
ps=example_39.ps

# Evaluate the first 180, 90, and 30 order/degrees of Venus spherical
# harmonics topography model, skipping the L = 0 term (radial mean).
# File truncated from http://www.ipgp.fr/~wieczor/SH/VenusTopo180.txt.zip
# Wieczorek, M. A., Gravity and topography of the terrestrial planets,
#   Treatise on Geophysics, 10, 165-205, doi:10.1016/B978-044452748-6/00156-5, 2007

gmt sph2grd @VenusTopo180.txt -I1 -Rg -Ng -Gv1.nc -F1/1/25/30
gmt sph2grd @VenusTopo180.txt -I1 -Rg -Ng -Gv2.nc -F1/1/85/90
gmt sph2grd @VenusTopo180.txt -I1 -Rg -Ng -Gv3.nc -F1/1/170/180
gmt grd2cpt v3.nc -Crainbow -E > t.cpt
gmt grdimage v1.nc -I+a45+nt0.75 -JG90/30/5i -P -K -Bg -Ct.cpt -X3i -Y1.1i > $ps
echo 4 4.5 L = 30 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
gmt psscale --FORMAT_FLOAT_MAP="%'g" -Ct.cpt -O -K -Dx1.25i/-0.2i+jTC+w5.5i/0.1i+h -Bxaf -By+lm >> $ps
gmt grdimage v2.nc -I+a45+nt0.75 -JG -O -K -Bg -Ct.cpt -X-1.25i -Y1.9i >> $ps
echo 4 4.5 L = 90 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
gmt grdimage v3.nc -I+a45+nt0.75 -JG -O -K -Bg -Ct.cpt -X-1.25i -Y1.9i >> $ps
echo 4 4.5 L = 180 | gmt pstext -R0/6/0/6 -Jx1i -O -K -Dj0.2i -F+f16p+jLM -N >> $ps
echo 3.75 5.4 Venus Spherical Harmonic Model | gmt pstext -R0/6/0/6 -Jx1i -O -F+f24p+jCM -N >> $ps
rm -f v?.nc t.cpt
